@@ -33,6 +33,7 @@ from mlcvzoo_base.evaluation.object_detection.metrics_logging import (
 from mlcvzoo_base.evaluation.object_detection.model_evaluation import (
     evaluate_with_model,
 )
+from mlcvzoo_base.evaluation.object_detection.utils import generate_metric_table
 
 from mlcvzoo_util.model_evaluator.configuration import ModelEvaluatorConfig
 from mlcvzoo_util.model_evaluator.structs import CheckpointInfo, CheckpointLoggingModes
@@ -112,7 +113,7 @@ class ODMetricFactory(
         Returns:
             A CheckpointInfo object stating the best checkpoint
         """
-        best_checkpoint = CheckpointInfo(path="", score=0.0)
+        best_checkpoint = CheckpointInfo(path="", score=-1.0)
 
         for ckpt, model_metrics in evaluated_checkpoint_metrics.items():
             current_map = MetricsComputation.compute_average_ap(
@@ -132,7 +133,7 @@ class ODMetricFactory(
     ) -> None:
         if not mlflow.active_run():
             logger.warning(
-                "No mlflow run is active, logging of checkpoint(s) as artifacts"
+                "No mlflow run is active, logging of checkpoint(s) as artifacts "
                 "will not take place"
             )
             return
@@ -174,6 +175,19 @@ class ODMetricFactory(
         """
         logger.info(f"Log results after evaluation")
 
+        logger.info(
+            generate_metric_table(
+                metrics_dict=evaluated_checkpoint_metrics[
+                    best_checkpoint.path
+                ].metrics_dict,
+                iou_threshold=list(
+                    evaluated_checkpoint_metrics[
+                        best_checkpoint.path
+                    ].metrics_dict.keys()
+                )[0],
+            ).table
+        )
+
         if logging_configs:
             for logging_config in logging_configs:
                 if isinstance(logging_config, TensorboardLoggingConfig):
