@@ -8,19 +8,13 @@ Module for defining enums and structs that are used across the
 model_evaluator package.
 """
 from dataclasses import dataclass
-from enum import auto
-
-try:
-    # python3.11
-    from enum import StrEnum  # type: ignore
-except ImportError:
-    from backports.strenum import StrEnum
+from enum import Enum, auto
 
 
-class CheckpointLoggingModes(StrEnum):
-    BEST = auto()
-    ALL = auto()
-    NONE = auto()
+class CheckpointLoggingModes(Enum):
+    BEST = "best"
+    ALL = "all"
+    NONE = "none"
 
 
 @dataclass
