@@ -6,18 +6,20 @@
 """
 Module for parsing information from yaml in python accessible attributes for the ModelSuite class.
 """
-from typing import List
 
 import related
+from attr import define
 from config_builder import BaseConfigClass
 from mlcvzoo_base.configuration.model_config import ModelConfig
 
 
-@related.mutable(strict=False)
+@define
 class ModelTrainerConfig(BaseConfigClass):
     """
     Class for parsing general information about the model suite and also further information
     in respective hierarchy
     """
 
+    __related_strict__ = True
+
     model_config: ModelConfig = related.ChildField(cls=ModelConfig)
